@@ -1,15 +1,19 @@
 from __future__ import annotations
 import re
 import warnings
+
+from typing import Callable
 from .types import (
-    FunctionInputParam,
-    FunctionOutputParam,
     string_to_type,
     type_to_string,
+    cast_to_type,
+)
+
+from .ser_types import (
+    FunctionInputParam,
+    FunctionOutputParam,
     DocstringParserResult,
     TypeNotFoundError,
-    Callable,
-    cast_to_type,
 )
 
 
@@ -246,7 +250,11 @@ def parse_restructured_docstring(docstring: str) -> DocstringParserResult:
             else:
                 param["optional"] = False
             if _type:
-                param["type"] = string_to_type(_type)
+                try:
+                    param["type"] = string_to_type(_type)
+                except Exception:
+                    pass
+
         elif section.startswith(":raises"):
             rsection = section.replace(":raises", "").strip()
             if ":" in rsection:
@@ -270,7 +278,10 @@ def parse_restructured_docstring(docstring: str) -> DocstringParserResult:
             if len(result["output_params"]) == 0:
                 raise ValueError("Type section without return")
             rsection = section.replace(":rtype:", "").strip()
-            result["output_params"][0]["type"] = string_to_type(rsection)
+            try:
+                result["output_params"][0]["type"] = string_to_type(rsection)
+            except Exception:
+                pass
 
     return _unify_parser_results(result, docstring=original_)
 
@@ -319,11 +330,11 @@ def parse_google_docstring(docstring: str) -> DocstringParserResult:
 
     diffs = [len(line) - len(lines[i]) for i, line in enumerate(pre_strip_lines)]
 
-    if (len(set(diffs))) > 2:
-        warnings.warn(
-            "More than two different initendation levels which might come from invalid formatted docstrings."
-            f"Docstring:\n{docstring}"
-        )
+    # if (len(set(diffs))) > 2:
+    #     warnings.warn(
+    #         "More than two different initendation levels which might come from invalid formatted docstrings."
+    #         f"Docstring:\n{docstring}"
+    #     )
 
     section_intentation = (
         min(diffs) if len(diffs) > 0 else 0
@@ -392,7 +403,11 @@ def parse_google_docstring(docstring: str) -> DocstringParserResult:
                     description = None
 
                 else:
-                    last_param["description"] += " " + line
+                    last_param["description"] = (
+                        last_param["description"] + " " + line
+                        if "description" in last_param
+                        else line
+                    )
                     continue
 
                 optional = False
@@ -412,7 +427,10 @@ def parse_google_docstring(docstring: str) -> DocstringParserResult:
                     "optional": optional,
                 }
                 if paramtype:
-                    param["type"] = string_to_type(paramtype)
+                    try:
+                        param["type"] = string_to_type(paramtype)
+                    except Exception:
+                        pass
                 del paramtype
                 result["input_params"].append(param)
                 last_param = param
@@ -420,9 +438,13 @@ def parse_google_docstring(docstring: str) -> DocstringParserResult:
                 return_match = re.match(r"([\w\[\], ]+): (.+)", line)
                 if return_match:
                     return_param = {
-                        "type": string_to_type(return_match.group(1)),
                         "description": return_match.group(2),
                     }
+                    try:
+                        return_param["type"] = string_to_type(return_match.group(1))
+                    except Exception:
+                        pass
+
                     result["output_params"].append(return_param)
                     last_param = return_param
                 elif last_param:
@@ -511,6 +533,7 @@ def parse_numpy_docstring(docstring: str) -> DocstringParserResult:
                     .strip(),
                     type=stype,
                     description="",
+                    positional="optional" not in param_match.group(2),
                     optional="optional" in param_match.group(2),
                 )
                 current_param_intendation = len(line) - len(line.lstrip())
